/*
For general Scribus (>=1.3.2) copyright and licensing information please refer
to the COPYING file provided with the program. Following this notice may exist
a copyright and/or license notice that predates the release of Scribus 1.3.2
for which a new license (GPL+exception) is in place.
*/
/*
 *  styleoptions.h
 *  ScribusCVS
 *
 *  Created by Andreas Vox on 20.08.05.
 *  Copyright 2005 under GPL2. All rights reserved.
 *
 */

#ifndef STYLEOPTIONS_H
#define STYLEOPTIONS_H

#ifdef Q_OS_MAC
#define AQUA_EXTRA 20
#else
#define AQUA_EXTRA 0
#endif

#endif
